@@ -14,9 +14,15 @@ public class Constants {
 	public final static String DEFAULT_SCOPE = "/gcube/devNext/NextNext";
 	public final static String DEFAULT_TOKEN = "";
 	
+	public static final String DEFAULT_ROLE = "OrganizationMember";
+	
+	//Data Miner Service Endpoint
 	public static final String DATAMINER_SERVICE_CATEGORY = "DataAnalysis";
 	public static final String DATA_MINER_SERVICE_NAME = "DataMiner";
-
+	
+	//Default Service Info Category
+	public static final String DEFAULT_SERVICE_INFO_CATEGORY = "Generic";
+	
 	// WPS Data Miner
 	public static final String WPSWebProcessingService = "WebProcessingService";
 	public static final String WPSCancelComputationServlet = "CancelComputationServlet";
